--
-- Catalina adds four functions to Lua:
-- 
-- delay(milliseconds) : Just delay by the specified number of milliseconds.
-- 
-- send(string) : Send a string to the loaded program.
-- 
-- receive(count, timeout) : Receive up to 'count' characters from the loaded
--                           program, with a timeout of 'timeout' milliseconds.
--                           Reads are terminated by a linefeed, and the 
--                           characters received are returned as a string.
--
-- wait_for(prompt, timeout) : Wait for the 'prompt' to be sent by the loaded
--                             program. The read is not terminated by a 
--                             linefeed, but will be terminated after 'timeout'
--                             milliseconds. If 'prompt' is an empty string, 
--                             the read will be terminated by any character
--                             (which will be returned).
--
-- NOTE: The script below uses the built-in Lua "error" function to report
-- errors - this is for testing only, as this immediately terminates the
-- script. Normally, it would be better to report the errors ourselves and 
-- then terminate the script a bit more gracefully!
--

print("\nLua script started\n");

str1 = "Hello from Lua!\n";
str2 = "";

-- delay a few milliseconds (allows for the loaded program to start)
delay(250);

-- send a string to the loaded program
send(str1);

-- receive a string up to 100 characters, with a timeout of 1000 milliseconds
str2 = receive(100, 1000);

if (str1 == str2) then 
   print("Sent string echoed correctly:", str2);
else
   error("Sent string NOT echoed correctly");
end

str1 = "done!"
str2 = "";
-- wait for a specified string, with a timeout of 1000 milliseconds
str2 = wait_for(str1, 1000);

if (str1 == str2) then
   print("Received correct string:", str2, "\n");
else
   error("Received incorrect string\n");
end

str2 = wait_for("\n", 1000);

if (str2 == "\n") then
   print("Received expected linefeed character\n");
else
   error("Received unexpected character\n");
end

print("Lua script completed - no errors detected!\n");
